@@ -2,11 +2,12 @@ use strict;
 use warnings;
 package Perlbal::Plugin::SessionAffinity;
 {
-  $Perlbal::Plugin::SessionAffinity::VERSION = '0.008';
+  $Perlbal::Plugin::SessionAffinity::VERSION = '0.010';
 }
 # ABSTRACT: Sane session affinity (sticky sessions) for Perlbal
 
 use Perlbal;
+use Hash::Util;
 use CGI::Cookie;
 use Digest::SHA 'sha1_hex';
 
@@ -221,6 +222,19 @@ sub register {
                 }
             }
 
+            # restricted hashes are stupid
+            # so we have to use the API to add them
+            foreach my $hook_name ( keys %{ $svc->{'hooks'} } ) {
+                foreach my $set ( @{ $svc->{'hooks'}{$hook_name} } ) {
+                    my ( $plugin, $sub ) = @{$set};
+                    $nodeservice->register_hook( $plugin, $hook_name, $sub );
+                }
+            }
+
+            # add all the extra config and extra headers
+            $nodeservice->{'extra_config'}  = $svc->{'extra_config'};
+            $nodeservice->{'extra_headers'} = $svc->{'extra_headers'};
+
             $nodeservice->set( pool => $poolid );
 
             $Perlbal::service{$serviceid} = $nodeservice;
@@ -314,7 +328,7 @@ sub unregister {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -324,7 +338,7 @@ Perlbal::Plugin::SessionAffinity - Sane session affinity (sticky sessions) for P
 
 =head1 VERSION
 
-version 0.008
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -393,6 +407,13 @@ plugin uses a completely different method which emphasizes correctness and
 the least intervention with Perlbal itself, and keeps Perlbal in charge of
 the critical operations.
 
+Small note here: this does not mean it will definitely play nice with
+everything you already have. Specifically any hooks that rely on the name of
+the service might be affected.
+
+Please read further under B<Incompatibilities> to understand the issue
+better.
+
 =item * Much less security risk
 
 Unlike the other plugin, which sets a cookie with the backend ID correlating
@@ -446,6 +467,24 @@ with existing connections) instead of firing new ones. It doesn't open a new
 socket for listening or anything like that. This also means your SSL
 connections work seamlessly. Yes, it's insanely cool, I know! :)
 
+=head2 Incompatibilities
+
+If you've read the B<Advanced stuff> section above, you might have guessed
+a possible problem with anything that relies on the name of the service.
+
+If you're using a plugin that relies on the name of the service, you might
+notice it stops working properly. This is because the new service that is
+generated by B<SessionAffinity> is no longer the previous service, and doesn't
+contain its name. Instead it has its own name, which is not known to your
+plugin.
+
+If you're using the C<header> command to add headers to the backend, fear
+not. We copy over the headers from the original service to the new one. That
+still works just fine.
+
+One possible way to fix it (implemented and later removed) is to include the
+previous name in a new unofficial (and unauthorized) key in the service hash.
+
 =head1 ATTRIBUTES
 
 =head2 affinity_cookie_header
@@ -581,13 +620,9 @@ Sawyer X <xsawyerx@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Sawyer X.
+This software is copyright (c) 2013 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
